==> stringee-android-sdk-dev-2.1.3.2-sources.jar: com/stringee/network/processor/ChatMessageReport.java <==
package com.stringee.network.processor;

import com.stringee.StringeeClient;
import com.stringee.common.Common;
import com.stringee.common.Constant;
import com.stringee.common.Utils;
import com.stringee.common.event.EventManager;
import com.stringee.database.DBHandler;
import com.stringee.exception.StringeeError;
import com.stringee.listener.StatusListener;
import com.stringee.messaging.Conversation;
import com.stringee.messaging.Message;
import com.stringee.messaging.StringeeChange;
import com.stringee.messaging.listeners.CallbackListener;
import com.stringee.network.tcpclient.packet.Packet;

import org.json.JSONException;

public class ChatMessageReport extends ProcessorBase {
    @Override
    public void process(StringeeClient client, final Packet packet) {
        client.getExecutor().execute(() -> {
            packet.decodeJson();
            try {
                int r = packet.getFieldInt("r");
                int requestId = packet.getFieldInt("requestId");
                StatusListener statusListener = Common.statusListenerMap.get(requestId);
                if (r == 0) {
                    if (statusListener != null) {
                        statusListener.onSuccess();
                    }
                    Message message = client.getMessagesMap().get(requestId);
                    if (message != null) {
                        client.getDbExecutor().execute(() -> DBHandler.getInstance(client.getContext()).updateMessagesState(Constant.MESSAGE_STATE_READ, message.getSequence(), message.getConversationId(), client.getUserId(), message.getMsgType().getValue()));
                        client.getConversationFromServer(message.getConversationId(), new CallbackListener<Conversation>() {
                            @Override
                            public void onSuccess(Conversation conv) {
                                EventManager.sendChatChangeEvent(client, new StringeeChange(StringeeChange.Type.UPDATE, conv));
                            }
                        });
                        client.getMessagesMap().remove(requestId);
                    }
                } else {
                    if (statusListener != null) {
                        statusListener.onError(new StringeeError(-1, "Failed to send a message report."));
                    }
                }
            } catch (JSONException e) {
                Utils.reportException(ChatMessageReport.class, e);
            }

        });
    }
}

==> stringee-android-sdk-dev-2.1.7-sources.jar: com/stringee/network/processor/ChatMessageReport.java <==
package com.stringee.network.processor;

import com.stringee.StringeeClient;
import com.stringee.common.Common;
import com.stringee.common.Constant;
import com.stringee.common.Utils;
import com.stringee.common.event.EventManager;
import com.stringee.database.DBHandler;
import com.stringee.exception.StringeeError;
import com.stringee.listener.StatusListener;
import com.stringee.messaging.Conversation;
import com.stringee.messaging.Message;
import com.stringee.messaging.StringeeChange;
import com.stringee.messaging.listeners.CallbackListener;
import com.stringee.network.tcpclient.packet.Packet;

import org.json.JSONException;

public class ChatMessageReport extends ProcessorBase {
    @Override
    public void process(StringeeClient client, final Packet packet) {
        client.executeExecutor(() -> {
            packet.decodeJson();
            try {
                int r = packet.getFieldInt("r");
                int requestId = packet.getFieldInt("requestId");
                StatusListener statusListener = Common.statusListenerMap.get(requestId);
                if (r == 0) {
                    if (statusListener != null) {
                        statusListener.onSuccess();
                    }
                    Message message = client.getMessagesMap().get(requestId);
                    if (message != null) {
                        client.executeDbExecutor(() -> DBHandler.getInstance(client.getContext()).updateMessagesState(Constant.MESSAGE_STATE_READ, message.getSequence(), message.getConversationId(), client.getUserId(), message.getMsgType().getValue()));
                        client.getConversationFromServer(message.getConversationId(), new CallbackListener<Conversation>() {
                            @Override
                            public void onSuccess(Conversation conv) {
                                EventManager.sendChatChangeEvent(client, new StringeeChange(StringeeChange.Type.UPDATE, conv));
                            }
                        });
                        client.getMessagesMap().remove(requestId);
                    }
                } else {
                    if (statusListener != null) {
                        statusListener.onError(new StringeeError(-1, "Failed to send a message report."));
                    }
                }
            } catch (JSONException e) {
                Utils.reportException(ChatMessageReport.class, e);
            }

        });
    }
}
